==> redux-source-with-notify-1.1.6.tgz: package/es6/withNotify.js <==
import "core-js/modules/web.dom.iterable";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { Component, createRef } from 'react';
import { createHoc } from 'react-common-kit';
export default function withNotify(config = {}) {
  const {
    trigger: Trigger,
    triggerProps = {},
    onSuccess,
    onError,
    sourceStateName = 'source',
    disbleErrorLogger = false,
    errorTexts = {},
    filter
  } = config;
  return createHoc(TargetComponent => class WithNotify extends Component {
    constructor(...args) {
      super(...args);
      this.trigger = createRef();
      this.state = {
        isPending: false,
        result: null,
        errors: [],
        hasNotify: false
      };
    }

    componentDidUpdate({
      [sourceStateName]: {
        isPending,
        result
      }
    }) {
      const {
        [sourceStateName]: {
          isPending: nextIsPending,
          errors: nextErrors,
          result: nextResult
        }
      } = this.props;

      if (result !== null && filter && !filter(result, nextResult) || !(isPending && !nextIsPending)) {
        return;
      }

      if (nextErrors.length) {
        onError(this.trigger.current, nextErrors);

        if (nextErrors.length && !disbleErrorLogger && typeof console === 'object' && console.error) {
          nextErrors.forEach(error => {
            if (!errorTexts[error.message]) {
              console.error(`${sourceStateName} error:`, error.stack || error);
            }
          });
        }
      } else {
        onSuccess(this.trigger.current);
      }
    }

    render() {
      const passThroughProps = _extends({}, this.props);

      return React.createElement("div", null, Trigger && React.createElement(Trigger, _extends({
        ref: this.trigger
      }, triggerProps)), React.createElement(TargetComponent, passThroughProps));
    }

  });
}

==> redux-source-with-notify-1.1.7.tgz: package/es6/withNotify.js <==
import "core-js/modules/web.dom.iterable";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { Component, createRef } from 'react';
import { createHoc } from 'react-common-kit';
export default function withNotify(config = {}) {
  const {
    trigger: Trigger,
    triggerProps = {},
    triggerPos = 'top',
    onSuccess,
    onError,
    sourceStateName = 'source',
    disbleErrorLogger = false,
    errorTexts = {},
    filter
  } = config;
  return createHoc(TargetComponent => class WithNotify extends Component {
    constructor(...args) {
      super(...args);
      this.trigger = createRef();
      this.state = {
        isPending: false,
        result: null,
        errors: [],
        hasNotify: false
      };
    }

    componentDidUpdate({
      [sourceStateName]: {
        isPending,
        result
      }
    }) {
      const {
        [sourceStateName]: {
          isPending: nextIsPending,
          errors: nextErrors,
          result: nextResult
        }
      } = this.props;

      if (result !== null && filter && !filter(result, nextResult) || !(isPending && !nextIsPending)) {
        return;
      }

      if (nextErrors.length) {
        onError(this.trigger.current, nextErrors);

        if (nextErrors.length && !disbleErrorLogger && typeof console === 'object' && console.error) {
          nextErrors.forEach(error => {
            if (!errorTexts[error.message]) {
              console.error(`${sourceStateName} error:`, error.stack || error);
            }
          });
        }
      } else {
        onSuccess(this.trigger.current);
      }
    }

    render() {
      const passThroughProps = _extends({}, this.props);

      const trigger = Trigger && React.createElement(Trigger, _extends({
        ref: this.trigger
      }, triggerProps));
      return React.createElement("div", null, triggerPos === 'top' && trigger, React.createElement(TargetComponent, passThroughProps), triggerPos === 'bottom' && trigger);
    }

  });
}
